//=============================================================================
// System  : CVMEditor - Virtual Memory Text Editor Library
// File    : CVMResource.h
// Author  : Eric Woodruff  (Eric_Woodruff@CompuServe.com)
// Updated : Wed 07/08/98 01:00:00
// Note    : Copyright 1998, Eric Woodruff, All rights reserved
// Compiler: Visual C++
//
// This contains the resource file definitions and command constants
// for CVMEditor.
//
// Version    Date    Who   Comments
// ============================================================================
// 1.0.0    06/05/97  EFW   Created the code
//=============================================================================

#if !defined(__CVMEDITOR_RH)
#define __CVMEDITOR_RH

#if defined(USE_MFC_DEFS)
#include "afxres.h"
#endif


// NOTE: These values should be okay.  If there's a conflict, I'll change it.

// Keyboard accelerator table identifiers
#define IDA_CVMEDIT_SINGLE_KEYS     301
#define IDA_CVMEDIT_BLOCK_KEYS      302
#define IDA_CVMEDIT_QUICK_KEYS      303
#define IDA_CVMEDIT_JUMP_KEYS       304
#define IDA_CVMEDIT_OPTION_KEYS     305
#define IDA_CVMEDIT_LITERAL         306

// String table IDs for the indicator messages
#define IDS_TWOKEY_MSG              350
#define IDS_LITERAL_MSG             351

// Starting command constant
#define CVM_FIRSTCMD        (WM_USER + 9000)

#define CVM_LOADTABLE1      CVM_FIRSTCMD        // Load secondary keypress
#define CVM_LOADTABLE2      CVM_FIRSTCMD + 1    // accelerator table cmds
#define CVM_LOADTABLE3      CVM_FIRSTCMD + 2
#define CVM_LOADTABLE4      CVM_FIRSTCMD + 3
#define CVM_LOADTABLE5      CVM_FIRSTCMD + 4
#define CVM_LOADTABLE6      CVM_FIRSTCMD + 5
#define CVM_LOADTABLE7      CVM_FIRSTCMD + 6
#define CVM_LOADTABLE8      CVM_FIRSTCMD + 7
#define CVM_LOADTABLE9      CVM_FIRSTCMD + 8
#define CVM_LOADTABLE10     CVM_FIRSTCMD + 9

#define CVM_AUTOWRAPMODE    CVM_FIRSTCMD + 10   // Non-destructive cmd events
#define CVM_INDENTMODE      CVM_FIRSTCMD + 11
#define CVM_INSMODE         CVM_FIRSTCMD + 12
#define CVM_TABSTYLE        CVM_FIRSTCMD + 13
#define CVM_TRAILINGSPC     CVM_FIRSTCMD + 14
#define CVM_WRAPMODE        CVM_FIRSTCMD + 15
#define CVM_WRAPONRESIZE    CVM_FIRSTCMD + 16

#define CVM_CHARLEFT        CVM_FIRSTCMD + 17
#define CVM_CHARRIGHT       CVM_FIRSTCMD + 18
#define CVM_WORDLEFT        CVM_FIRSTCMD + 19
#define CVM_WORDRIGHT       CVM_FIRSTCMD + 20
#define CVM_LINESTART       CVM_FIRSTCMD + 21
#define CVM_LINEEND         CVM_FIRSTCMD + 22
#define CVM_LINEUP          CVM_FIRSTCMD + 23
#define CVM_LINEDOWN        CVM_FIRSTCMD + 24
#define CVM_SHIFTUP         CVM_FIRSTCMD + 25
#define CVM_SHIFTDOWN       CVM_FIRSTCMD + 26
#define CVM_PAGEUP          CVM_FIRSTCMD + 27
#define CVM_PAGEDOWN        CVM_FIRSTCMD + 28
#define CVM_WINDOWTOP       CVM_FIRSTCMD + 29
#define CVM_WINDOWBOTM      CVM_FIRSTCMD + 30
#define CVM_TEXTSTART       CVM_FIRSTCMD + 31
#define CVM_TEXTEND         CVM_FIRSTCMD + 32

#define CVM_STARTSELECT     CVM_FIRSTCMD + 33
#define CVM_ENDSELECT       CVM_FIRSTCMD + 34
#define CVM_HIDESELECT      CVM_FIRSTCMD + 35
#define CVM_FINDMATCHING    CVM_FIRSTCMD + 36
#define CVM_TOGGLEBOOKMARK  CVM_FIRSTCMD + 37
#define CVM_NEXTBOOKMARK    CVM_FIRSTCMD + 38
#define CVM_PREVBOOKMARK    CVM_FIRSTCMD + 39
#define CVM_CLEARBOOKMARKS  CVM_FIRSTCMD + 40
// + 41 - unused
// + 42 - unused
#define CVM_GOTOLINE        CVM_FIRSTCMD + 43
#define CVM_JUMPBLKST       CVM_FIRSTCMD + 44
#define CVM_JUMPBLKEND      CVM_FIRSTCMD + 45
#define CVM_LASTCHG         CVM_FIRSTCMD + 46
#define CVM_PREVPOS         CVM_FIRSTCMD + 47
#define CVM_WRITEBLOCK      CVM_FIRSTCMD + 48
#define CVM_LOCALEDITOROPT  CVM_FIRSTCMD + 49

#define CVM_FIRSTDESTRUCTIVE CVM_FIRSTCMD + 50  // First destructive cmd event

#define CVM_BACKSPACE       CVM_FIRSTCMD + 50   // Must = CVM_FIRSTDESTRUCTIVE
#define CVM_DELCHAR         CVM_FIRSTCMD + 51
#define CVM_DELETETAB       CVM_FIRSTCMD + 52
#define CVM_DELWORDLEFT     CVM_FIRSTCMD + 53
#define CVM_DELWORDRIGHT    CVM_FIRSTCMD + 54
#define CVM_DELSTART        CVM_FIRSTCMD + 55
#define CVM_DELEND          CVM_FIRSTCMD + 56
#define CVM_DELLINE         CVM_FIRSTCMD + 57
#define CVM_NEWLINE         CVM_FIRSTCMD + 58
#define CVM_INSERTLINE      CVM_FIRSTCMD + 59
// + 60 - unused
#define CVM_INSERTTAB       CVM_FIRSTCMD + 61
#define CVM_RESTORELINE     CVM_FIRSTCMD + 62
#define CVM_COPYBLOCK       CVM_FIRSTCMD + 63
#define CVM_MOVEBLOCK       CVM_FIRSTCMD + 64
#define CVM_READFILE        CVM_FIRSTCMD + 65

#define CVM_ALIGNTEXT       CVM_FIRSTCMD + 66
#define CVM_CENTERLINES     CVM_FIRSTCMD + 67
#define CVM_FORCELOWER      CVM_FIRSTCMD + 68
#define CVM_FORCEUPPER      CVM_FIRSTCMD + 69
#define CVM_TOGGLECASE      CVM_FIRSTCMD + 70
#define CVM_INDENTBLOCK     CVM_FIRSTCMD + 71
#define CVM_UNINDENTBLOCK   CVM_FIRSTCMD + 72
#define CVM_WRAPPARA        CVM_FIRSTCMD + 73

#define CVM_FILESAVEALL     CVM_FIRSTCMD + 74
#define CVM_RESYNCHAPP      CVM_FIRSTCMD + 75
#define CVM_RESYNCHVIEW     CVM_FIRSTCMD + 76

#define CVM_LASTDESTRUCTIVE CVM_FIRSTCMD + 76   // Must equal last destructive
                                                // command event

#define CVM_BUFFEREXISTS    CVM_FIRSTCMD + 77   // Other command events

#define CVM_LASTCMD         CVM_BUFFEREXISTS

// The following are the "standard" commands common to most applications.
// An attempt is made to use the existing definitions based on compile-time
// definitions.  Note that this will make a DLL version library-specific
// (MFC, OWL, etc).  CVMEditor will use the CVM_xxx definitions.  Resource
// files can use the ID_xxxx definitions.

#if defined(USE_MFC_DEFS)

#define CVM_EDITFIND        ID_EDIT_FIND
#define CVM_EDITFINDNEXT    ID_EDIT_REPEAT
#define CVM_EDITREPLACE     ID_EDIT_REPLACE
#define CVM_EDITCLEAR       ID_EDIT_CLEAR
#define CVM_EDITCUT         ID_EDIT_CUT
#define CVM_EDITCOPY        ID_EDIT_COPY
#define CVM_EDITPASTE       ID_EDIT_PASTE
#define CVM_EDITUNDO        ID_EDIT_UNDO
#define CVM_EDITREDO        ID_EDIT_REDO
#define CVM_SELECT_ALL      ID_EDIT_SELECT_ALL

#else

#define CVM_EDITFIND        CVM_FIRSTCMD + 78
#define CVM_EDITFINDNEXT    CVM_FIRSTCMD + 79
#define CVM_EDITREPLACE     CVM_FIRSTCMD + 80
#define CVM_EDITCLEAR       CVM_FIRSTCMD + 81
#define CVM_EDITCUT         CVM_FIRSTCMD + 82
#define CVM_EDITCOPY        CVM_FIRSTCMD + 83
#define CVM_EDITPASTE       CVM_FIRSTCMD + 84
#define CVM_EDITUNDO        CVM_FIRSTCMD + 85
#define CVM_EDITREDO        CVM_FIRSTCMD + 86
#define CVM_SELECT_ALL      CVM_FIRSTCMD + 87

#endif

// Used to make CMFCEditorView bring up a font selection dialog box
// and alter the font for the selected view.
#define CVM_CHANGE_FONT         CVM_FIRSTCMD + 88

// Used to retrieve a CVMEditorWnd pointer to a memo field in a dialog
// template (CVMEditorWndClass)
#define CVM_GET_MEMO_OBJECT     CVM_FIRSTCMD + 89

// Can be used for status bar indicator update
#define ID_INDICATOR_CVMSTAT    CVM_FIRSTCMD + 90   // General status
#define ID_INDICATOR_CVMRO      CVM_FIRSTCMD + 91   // Read Only

#endif
