//=============================================================================
// System  : CVMEditor - Virtual Memory Text Editor Library
// File    : MFCEditorWnd.h
// Author  : Eric Woodruff  (Eric_Woodruff@CompuServe.com)
// Updated : Wed 07/08/98 01:00:00
// Note    : Copyright 1998, Eric Woodruff, All rights reserved
// Compiler: Visual C++
//
// An MFC CWnd-derived class used to encapsulate a CMFCEditor object for
// use in a dialog box.
//
// Version    Date    Who   Comments
// ============================================================================
// 1.0.0    06/08/97  EFW   Created the code
//=============================================================================

#if !defined(__MFCEDITORWND_H)
#define __MFCEDITORWND_H

#if defined(USE_CSHLIB)

#if !defined(__MFCCSHEDITOR_H)
#include "MFCCSHEditor.h"
#endif

#else

#if !defined(__MFCEDITOR_H)
#include "MFCEditor.h"
#endif

#endif

// Custom style for CMFCEditorWnd.  If enabled, the editor will handle
// TAB key presses.  If disabled, it will pass them on to the owner.
#define ES_WANTTAB  0x00004000

class CMFCEditorWnd : public CWnd
{
// Construction
public:
	CMFCEditorWnd();

// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CMFCEditorWnd)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	//}}AFX_VIRTUAL

// Implementation
public:
	virtual ~CMFCEditorWnd();

	// Generated message map functions
protected:
	//{{AFX_MSG(CMFCEditorWnd)
	afx_msg void OnPaint();
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg BOOL OnEraseBkgnd(CDC* pDC);
	afx_msg BOOL OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
    afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
    afx_msg void OnKeyUp(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKillFocus(CWnd* pNewWnd);
	afx_msg void OnSetFocus(CWnd* pOldWnd);
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg UINT OnGetDlgCode();
	afx_msg int OnMouseActivate(CWnd* pDesktopWnd, UINT nHitTest, UINT message);
	afx_msg void OnEditcopy();
	afx_msg void OnEditcut();
	afx_msg void OnEditpaste();
	afx_msg void OnEditClear();
	afx_msg void OnEditSelectAll();
	afx_msg void OnEditFind();
	afx_msg void OnEditRedo();
	afx_msg void OnEditRepeat();
	afx_msg void OnEditReplace();
	afx_msg void OnEditUndo();
	afx_msg BOOL OnNcCreate(LPCREATESTRUCT lpCreateStruct);
    afx_msg BOOL OnMouseWheel(UINT fFlags, short zDelta, CPoint point);
	//}}AFX_MSG

    afx_msg void OnEditorCommands(UINT nCmd);

	DECLARE_MESSAGE_MAP()

protected:
    int keyState;

public:

#if defined(USE_CSHLIB)
    CMFCCSHEditor *editor;      // Color syntax highlighting editor
#else
    CMFCEditor *editor;         // Non-highlighting editor
#endif

	static BOOL RegisterControlClass();

    void SetFontInfo(CFont &font);

protected:
    HACCEL hAccel;

	virtual void PostNcDestroy();
	static LRESULT CALLBACK EXPORT WndProcHook(HWND, UINT, WPARAM, LPARAM);

    long OnGetMemoObject(WPARAM wParam, LPARAM lParam);
};

/////////////////////////////////////////////////////////////////////////////
// MFC Dialog DDX helpers

void AFXAPI DDX_CVMEditorCtl(CDataExchange *pDX, int nIDC,
    CMFCEditorWnd **pEdit);
void AFXAPI DDX_CVMEditorText(CDataExchange *pDX, int nIDC, CString &value);

#endif
