// CGlobalOptions.cpp : implementation file
//

#include "stdafx.h"

#include "MFCEditorDoc.h"

#include "MFCSDI.h"
#include "MainFrm.h"
#include "GlobalOptions.h"
#include "IniFile.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CGlobalOptions

IMPLEMENT_DYNAMIC(CGlobalOptions, CPropertySheet)

CGlobalOptions::CGlobalOptions(UINT nIDCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(nIDCaption, pParentWnd, iSelectPage)
{
    // Hide the Apply button as we don't need it
    m_psh.dwFlags |= PSH_NOAPPLYNOW;

    // Add pages in the order they are to appear on the tabs
    AddPage(&m_Startup);
    AddPage(&m_General);
    AddPage(&m_Search);
    AddPage(&m_File);
    AddPage(&m_AutoSave);
}

CGlobalOptions::~CGlobalOptions()
{
}


BEGIN_MESSAGE_MAP(CGlobalOptions, CPropertySheet)
	//{{AFX_MSG_MAP(CGlobalOptions)
		// NOTE - the ClassWizard will add and remove mapping macros here.
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////

// Set options in the dialog from the global editor options structure
void CGlobalOptions::SetOptions(GlobalEditorOptions &gblOpts,
    int nAutoSaveFlags, int nAutoSaveInterval)
{
    m_Startup.m_bShowGutter = (CMFCEditor::nDefGutter != 0);
    m_Startup.m_bUseAutoEOL =
        ((CVMEditor::GlobalOpts.nEnterMatch & efAutoEOLMark) != 0);

    m_Startup.m_nEditBufSize = CMFCEditorDoc::nBufSize;
    m_Startup.m_nMaxEditMem = CVirtualMemory::getMaxAllocation();

    m_General.m_bAutoIndent = ((gblOpts.lOperation & efAutoIndent) != 0);
    m_General.m_bWrapMode = ((gblOpts.lOperation & efWordWrap) != 0);
    m_General.m_bAutoWordWrap = ((gblOpts.lOperation & efAutoWrap) != 0);
    m_General.m_bWrapOnResize = ((gblOpts.lOperation & efWrapOnResize) != 0);
    m_General.m_bTrailingSpaces = ((gblOpts.lOperation & efTrailingSpaces) != 0);
    m_General.m_bUseHardTabs = ((gblOpts.lOperation & efUseHardTabs) != 0);
    m_General.m_bCanUndoRedo = ((gblOpts.lOperation & efCanUndo) != 0);
    m_General.m_bNonPersBlocks = ((gblOpts.lOperation & efNonPersistentBlocks) != 0);
    m_General.m_bOverwriteBlocks = ((gblOpts.lOperation & efAllowOverwrite) != 0);

    m_General.m_nSignsInterval = gblOpts.nReportInterval;
    m_General.m_nSignsStart = gblOpts.nInitThreshold;
    m_General.m_nTabSize = gblOpts.nTabSize;
    m_General.m_nIndentSize = gblOpts.nIndentSize;
    m_General.m_nRightMargin = gblOpts.nRightMargin;

    m_Search.m_bEMParens = ((gblOpts.nEnterMatch & efParen) != 0);
    m_Search.m_bEMBrackets = ((gblOpts.nEnterMatch & efBracket) != 0);
    m_Search.m_bEMBraces = ((gblOpts.nEnterMatch & efBrace) != 0);
    m_Search.m_bEMSngQuotes = ((gblOpts.nEnterMatch & efSngQuote) != 0);
    m_Search.m_bEMDblQuotes = ((gblOpts.nEnterMatch & efDblQuote) != 0);
    m_Search.m_bEMAngBrkts = ((gblOpts.nEnterMatch & efAngBracket) != 0);

    m_Search.m_bCaseSensitive = ((gblOpts.nSearch & efCaseSensitive) != 0);
    m_Search.m_bWholeWordsOnly = ((gblOpts.nSearch & efWholeWordsOnly) != 0);
    m_Search.m_bPromptOnReplace = ((gblOpts.nSearch & efPromptOnReplace) != 0);

    m_File.m_bExpandTabs = ((gblOpts.lOperation & efExpandTabs) != 0);
    m_File.m_bCreateBackups = ((gblOpts.lOperation & efBackupFiles) != 0);
    m_File.m_bUseLFOnly = ((gblOpts.lOperation & efUseLFOnly) != 0);
    m_File.m_bReadOnly = ((gblOpts.lOperation & efReadOnly) != 0);
    m_File.m_bCheckRO = ((gblOpts.lOperation & efSetROonLoad) != 0);

    m_File.m_csBackupExt = gblOpts.szBackupExt;
    m_File.m_csDefaultExt = gblOpts.szDefaultExt;

    m_File.m_bResynchApp = ((gblOpts.lOperation & efResynchAppPrompt) != 0);
    m_File.m_bResynchView = ((gblOpts.lOperation & efResynchViewPrompt) != 0);
    m_File.m_bResynchViewNever = ((gblOpts.lOperation & efResynchViewNever) != 0);
    m_File.m_bResynchNever = ((gblOpts.lOperation & efResynchNever) != 0);

    m_AutoSave.m_bAutoSaveEnabled = ((nAutoSaveFlags & asAutoSaveEnabled) != 0);
    m_AutoSave.m_bSaveOnSwitch = ((nAutoSaveFlags & asSaveOnSwitch) != 0);
    m_AutoSave.m_nSaveInterval = nAutoSaveInterval;
}

// Get options from the dialog into the global editor options structure
void CGlobalOptions::GetOptions(GlobalEditorOptions &gblOpts,
    int &nAutoSaveFlags, int &nAutoSaveInterval)
{
    // Clear all flags
    gblOpts.lOperation = gblOpts.nEnterMatch = gblOpts.nSearch =
        nAutoSaveFlags = 0;

    // Get all of the settings
    if(m_Startup.m_bShowGutter)
        CMFCEditor::nDefGutter = DEF_GUTTER_SIZE;
    else
        CMFCEditor::nDefGutter = 0;

    if(m_Startup.m_bUseAutoEOL)
    {
        CVMEditor::GlobalOpts.nEnterMatch |= efAutoEOLMark;
        CVMEditor::chEOLMarker = '\x07';
    }
    else
        CVMEditor::GlobalOpts.nEnterMatch &= ~efAutoEOLMark;

    CMFCEditorDoc::nBufSize = m_Startup.m_nEditBufSize;
    CVirtualMemory::setMaxAllocation(m_Startup.m_nMaxEditMem);

    if(m_General.m_bAutoIndent)
        gblOpts.lOperation |= efAutoIndent;
    if(m_General.m_bWrapMode)
        gblOpts.lOperation |= efWordWrap;
    if(m_General.m_bAutoWordWrap)
        gblOpts.lOperation |= efAutoWrap;
    if(m_General.m_bWrapOnResize)
        gblOpts.lOperation |= efWrapOnResize;
    if(m_General.m_bTrailingSpaces)
        gblOpts.lOperation |= efTrailingSpaces;
    if(m_General.m_bUseHardTabs)
        gblOpts.lOperation |= efUseHardTabs;
    if(m_General.m_bCanUndoRedo)
        gblOpts.lOperation |= efCanUndo;
    if(m_General.m_bNonPersBlocks)
        gblOpts.lOperation |= efNonPersistentBlocks;
    if(m_General.m_bOverwriteBlocks)
        gblOpts.lOperation |= efAllowOverwrite;

    gblOpts.nReportInterval = m_General.m_nSignsInterval;
    gblOpts.nInitThreshold = m_General.m_nSignsStart;
    gblOpts.nTabSize = m_General.m_nTabSize;
    gblOpts.nIndentSize = m_General.m_nIndentSize;
    gblOpts.nRightMargin = m_General.m_nRightMargin;

    if(m_Search.m_bEMParens)
        gblOpts.nEnterMatch |= efParen;
    if(m_Search.m_bEMBrackets)
        gblOpts.nEnterMatch |= efBracket;
    if(m_Search.m_bEMBraces)
        gblOpts.nEnterMatch |= efBrace;
    if(m_Search.m_bEMSngQuotes)
        gblOpts.nEnterMatch |= efSngQuote;
    if(m_Search.m_bEMDblQuotes)
        gblOpts.nEnterMatch |= efDblQuote;
    if(m_Search.m_bEMAngBrkts)
        gblOpts.nEnterMatch |= efAngBracket;

    if(m_Search.m_bCaseSensitive)
        gblOpts.nSearch |= efCaseSensitive;
    if(m_Search.m_bWholeWordsOnly)
        gblOpts.nSearch |= efWholeWordsOnly;
    if(m_Search.m_bPromptOnReplace)
        gblOpts.nSearch |= efPromptOnReplace;

    if(m_File.m_bExpandTabs)
        gblOpts.lOperation |= efExpandTabs;
    if(m_File.m_bCreateBackups)
        gblOpts.lOperation |= efBackupFiles;
    if(m_File.m_bUseLFOnly)
        gblOpts.lOperation |= efUseLFOnly;
    if(m_File.m_bReadOnly)
        gblOpts.lOperation |= efReadOnly;
    if(m_File.m_bCheckRO)
        gblOpts.lOperation |= efSetROonLoad;

    strcpy(gblOpts.szBackupExt, m_File.m_csBackupExt);
    strcpy(gblOpts.szDefaultExt, m_File.m_csDefaultExt);

    if(m_File.m_bResynchApp)
        gblOpts.lOperation |= efResynchAppPrompt;
    if(m_File.m_bResynchView)
        gblOpts.lOperation |= efResynchViewPrompt;
    if(m_File.m_bResynchViewNever)
        gblOpts.lOperation |= efResynchViewNever;
    if(m_File.m_bResynchNever)
        gblOpts.lOperation |= efResynchNever;

    if(m_AutoSave.m_bAutoSaveEnabled)
        nAutoSaveFlags |= asAutoSaveEnabled;
    if(m_AutoSave.m_bSaveOnSwitch)
        nAutoSaveFlags |= asSaveOnSwitch;

    nAutoSaveInterval = m_AutoSave.m_nSaveInterval;
}

/////////////////////////////////////////////////////////////////////////////
// CGlobalOptions message handlers
