// CLocalEditorOpts->cpp : implementation file
//

#include "stdafx.h"
#include "MFCSDI.h"

#include "CVMEditorDefs.h"
#include "LocalEditorOpts.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CLocalEditorOpts dialog


CLocalEditorOpts::CLocalEditorOpts(CWnd* pParent /*=NULL*/)
	: CDialog(CLocalEditorOpts::IDD, pParent)
{
	//{{AFX_DATA_INIT(CLocalEditorOpts)
	m_bAutoIndent = FALSE;
	m_bAutoWordWrap = FALSE;
	m_bCanUndoRedo = FALSE;
	m_nIndentSize = 0;
	m_bNonPersBlocks = FALSE;
	m_bOverwriteBlocks = FALSE;
	m_nRightMargin = 0;
	m_nTabSize = 0;
	m_bTrailingSpaces = FALSE;
	m_bUseHardTabs = FALSE;
	m_bWrapMode = FALSE;
	m_bWrapOnResize = FALSE;
	m_bEMAngBrkts = FALSE;
	m_bEMBraces = FALSE;
	m_bEMBrackets = FALSE;
	m_bEMDblQuotes = FALSE;
	m_bEMParens = FALSE;
	m_bEMSngQuotes = FALSE;
	//}}AFX_DATA_INIT
}


void CLocalEditorOpts::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CLocalEditorOpts)
	DDX_Check(pDX, IDC_AUTOINDENTMODE, m_bAutoIndent);
	DDX_Check(pDX, IDC_AUTOWORDWRAP, m_bAutoWordWrap);
	DDX_Check(pDX, IDC_CANUNDOREDO, m_bCanUndoRedo);
	DDX_Text(pDX, IDC_INDENTSIZE, m_nIndentSize);
	DDV_MinMaxInt(pDX, m_nIndentSize, 3, 16);
	DDX_Check(pDX, IDC_NONPERSBLOCKS, m_bNonPersBlocks);
	DDX_Check(pDX, IDC_OVERWRITEBLKS, m_bOverwriteBlocks);
	DDX_Text(pDX, IDC_RIGHTMARGIN, m_nRightMargin);
	DDV_MinMaxInt(pDX, m_nRightMargin, 4, 256);
	DDX_Text(pDX, IDC_TABSIZE, m_nTabSize);
	DDV_MinMaxInt(pDX, m_nTabSize, 3, 16);
	DDX_Check(pDX, IDC_TRAILINGSPACES, m_bTrailingSpaces);
	DDX_Check(pDX, IDC_USEHARDTABS, m_bUseHardTabs);
	DDX_Check(pDX, IDC_WORDWRAPMODE, m_bWrapMode);
	DDX_Check(pDX, IDC_WRAPONRESIZE, m_bWrapOnResize);
	DDX_Check(pDX, IDC_EMANGBRKTS, m_bEMAngBrkts);
	DDX_Check(pDX, IDC_EMBRACES, m_bEMBraces);
	DDX_Check(pDX, IDC_EMBRACKET, m_bEMBrackets);
	DDX_Check(pDX, IDC_EMDBLQUOTES, m_bEMDblQuotes);
	DDX_Check(pDX, IDC_EMPAREN, m_bEMParens);
	DDX_Check(pDX, IDC_EMSNGQUOTES, m_bEMSngQuotes);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CLocalEditorOpts, CDialog)
	//{{AFX_MSG_MAP(CLocalEditorOpts)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CLocalEditorOpts message handlers

// Set options in the dialog from the local editor options structure
void CLocalEditorOpts::SetOptions(LocalEditorOptions *lclOpts)
{
    m_nIndentSize = lclOpts->nIndentSize;
    m_nRightMargin = lclOpts->nRightMargin;
    m_nTabSize = lclOpts->nTabSize;

    m_bAutoIndent = ((lclOpts->lOperation & efAutoIndent) != 0);
    m_bAutoWordWrap = ((lclOpts->lOperation & efAutoWrap) != 0);
    m_bCanUndoRedo = ((lclOpts->lOperation & efCanUndo) != 0);
    m_bNonPersBlocks = ((lclOpts->lOperation & efNonPersistentBlocks) != 0);
    m_bOverwriteBlocks = ((lclOpts->lOperation & efAllowOverwrite) != 0);
    m_bTrailingSpaces = ((lclOpts->lOperation & efTrailingSpaces) != 0);
    m_bUseHardTabs = ((lclOpts->lOperation & efUseHardTabs) != 0);
    m_bWrapMode = ((lclOpts->lOperation & efWordWrap) != 0);
    m_bWrapOnResize = ((lclOpts->lOperation & efWrapOnResize) != 0);

    m_bEMAngBrkts = ((lclOpts->nEnterMatch & efAngBracket) != 0);
    m_bEMBraces = ((lclOpts->nEnterMatch & efBrace) != 0);
    m_bEMBrackets = ((lclOpts->nEnterMatch & efBracket) != 0);
    m_bEMDblQuotes = ((lclOpts->nEnterMatch & efDblQuote) != 0);
    m_bEMParens = ((lclOpts->nEnterMatch & efParen) != 0);
    m_bEMSngQuotes = ((lclOpts->nEnterMatch & efSngQuote) != 0);
}

// Get options from the dialog into the local editor options structure
void CLocalEditorOpts::GetOptions(LocalEditorOptions *lclOpts)
{
    lclOpts->nIndentSize = m_nIndentSize;
    lclOpts->nRightMargin = m_nRightMargin;
    lclOpts->nTabSize = m_nTabSize;

    // Turn off all the affected local option bits
    lclOpts->lOperation &= ~(efAutoIndent | efAutoWrap | efCanUndo | 
        efNonPersistentBlocks | efAllowOverwrite | efTrailingSpaces |
        efUseHardTabs | efWordWrap | efWrapOnResize);

    // Enable the new selections
    if(m_bAutoIndent)
        lclOpts->lOperation |= efAutoIndent;
    if(m_bAutoWordWrap)
        lclOpts->lOperation |= efAutoWrap;
    if(m_bCanUndoRedo)
        lclOpts->lOperation |= efCanUndo;
    if(m_bNonPersBlocks)
        lclOpts->lOperation |= efNonPersistentBlocks;
    if(m_bOverwriteBlocks)
        lclOpts->lOperation |= efAllowOverwrite;
    if(m_bTrailingSpaces)
        lclOpts->lOperation |= efTrailingSpaces;
    if(m_bUseHardTabs)
        lclOpts->lOperation |= efUseHardTabs;
    if(m_bWrapMode)
        lclOpts->lOperation |= efWordWrap;
    if(m_bWrapOnResize)
        lclOpts->lOperation |= efWrapOnResize;

    lclOpts->nEnterMatch = 0;

    if(m_bEMAngBrkts)
        lclOpts->nEnterMatch |= efAngBracket;
    if(m_bEMBraces)
        lclOpts->nEnterMatch |= efBrace;
    if(m_bEMBrackets)
        lclOpts->nEnterMatch |= efBracket;
    if(m_bEMDblQuotes)
        lclOpts->nEnterMatch |= efDblQuote;
    if(m_bEMParens)
        lclOpts->nEnterMatch |= efParen;
    if(m_bEMSngQuotes)
        lclOpts->nEnterMatch |= efSngQuote;
}
