// SetLineDlg.cpp : implementation file
//

#include "stdafx.h"

#include "Resource.h"

#include "CVMEditor.h"

#include "MFCEditorDoc.h"
#include "MFCEditorView.h"

#include "SetLineDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CSetLineDlg dialog


CSetLineDlg::CSetLineDlg(CWnd *pParent)
	: CDialog(CSetLineDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSetLineDlg)
	//}}AFX_DATA_INIT
}


void CSetLineDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSetLineDlg)
	DDX_Control(pDX, IDC_DELETE, m_btnDelete);
	DDX_Control(pDX, IDOK, m_btnGoto);
	DDX_Control(pDX, IDC_CURRENTFILE, m_scCurrentFile);
	DDX_Control(pDX, IDC_BOOKMARKS, m_lbBookmarks);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CSetLineDlg, CDialog)
	//{{AFX_MSG_MAP(CSetLineDlg)
	ON_LBN_DBLCLK(IDC_BOOKMARKS, OnOK)
	ON_BN_CLICKED(IDC_DELETE, OnDelete)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSetLineDlg message handlers

void CSetLineDlg::OnOK()
{
    long lLine;

    CMFCEditorView *pView;

    int nSel = m_lbBookmarks.GetCurSel();
    if(nSel == LB_ERR)
    {
        m_lbBookmarks.SetCurSel(0);
        return;
    }

#if !defined(USE_MDI)
    CFrameWnd* pFrame = dynamic_cast<CFrameWnd*>(AfxGetApp()->m_pMainWnd);
#else
    CMDIFrameWnd* pFrame =
        dynamic_cast<CMDIFrameWnd*>(AfxGetApp()->m_pMainWnd);
#endif

    if(pFrame)
    {
#if defined(USE_MDI)
        CMDIChildWnd *pWnd =
            dynamic_cast<CMDIChildWnd*>(pFrame->MDIGetActive());
        if(pWnd)
            pView = dynamic_cast<CMFCEditorView*>(pWnd->GetActiveView());
        else
            pView = NULL;
#else
        pView = dynamic_cast<CMFCEditorView*>(pFrame->GetActiveView());
#endif

        if(pView)
        {
            // Get the line number to jump to
            lLine = m_lbBookmarks.GetItemData(nSel);

            pView->editor->setCurrLine(lLine);
            pView->GetDocument()->UpdateAllViews(NULL);
        }
    }
// Stay here until cancel is hit
//	CDialog::OnOK();
}

// A better implementation could derive a new editor class
// and override the BookmarksChanged() function to broadcast
// the fact that bookmark information changed.
void CSetLineDlg::UpdateBookmarkList(void)
{
    CMFCEditorView *pView;

#if !defined(USE_MDI)
    CFrameWnd* pFrame = dynamic_cast<CFrameWnd*>(AfxGetApp()->m_pMainWnd);
#else
    CMDIFrameWnd* pFrame =
        dynamic_cast<CMDIFrameWnd*>(AfxGetApp()->m_pMainWnd);
#endif

    if(pFrame)
    {
#if defined(USE_MDI)
        CMDIChildWnd *pWnd =
            dynamic_cast<CMDIChildWnd*>(pFrame->MDIGetActive());
        if(pWnd)
            pView = dynamic_cast<CMFCEditorView*>(pWnd->GetActiveView());
        else
            pView = NULL;
#else
        pView = dynamic_cast<CMFCEditorView*>(pFrame->GetActiveView());
#endif

        if(pView)
        {
            m_lbBookmarks.ResetContent();

            CBkArray &Array = pView->editor->Buffer->Bookmarks;

            int nLBIdx, nCount = Array.GetCount();
            char szString[30];

            // Only add normal bookmarks to the list
            for(int nIdx = 0; nIdx < nCount; nIdx++)
                if(Array[nIdx]->nType == BK_NORMAL)
                {
                    sprintf(szString, "Line %ld", Array[nIdx]->lLine);
                    nLBIdx = m_lbBookmarks.AddString(szString);

                    // Use the line to jump to as the item data
                    if(nLBIdx != LB_ERR)
                        m_lbBookmarks.SetItemData(nLBIdx, Array[nIdx]->lLine);
                }

            if(m_lbBookmarks.GetCount())
            {
                m_btnGoto.EnableWindow(TRUE);
                m_btnDelete.EnableWindow(TRUE);
                m_scCurrentFile.SetWindowText(
                    pView->GetDocument()->GetPathName());
            }
            else
            {
                m_btnGoto.EnableWindow(FALSE);
                m_btnDelete.EnableWindow(FALSE);
                m_scCurrentFile.SetWindowText("No bookmarks");
            }
        }
    }
}

BOOL CSetLineDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

    UpdateBookmarkList();

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CSetLineDlg::OnDelete()
{
    long lLine;

    CMFCEditorView *pView;

    int nSel = m_lbBookmarks.GetCurSel();
    if(nSel == LB_ERR)
    {
        m_lbBookmarks.SetCurSel(0);
        return;
    }

#if !defined(USE_MDI)
    CFrameWnd* pFrame = dynamic_cast<CFrameWnd*>(AfxGetApp()->m_pMainWnd);
#else
    CMDIFrameWnd* pFrame =
        dynamic_cast<CMDIFrameWnd*>(AfxGetApp()->m_pMainWnd);
#endif

    if(pFrame)
    {
#if defined(USE_MDI)
        CMDIChildWnd *pWnd =
            dynamic_cast<CMDIChildWnd*>(pFrame->MDIGetActive());
        if(pWnd)
            pView = dynamic_cast<CMFCEditorView*>(pWnd->GetActiveView());
        else
            pView = NULL;
#else
        pView = dynamic_cast<CMFCEditorView*>(pFrame->GetActiveView());
#endif

        if(pView)
        {
            // Get the line number to jump to
            lLine = m_lbBookmarks.GetItemData(nSel);

            pView->editor->RemoveBookmark(BK_NORMAL, lLine);
            UpdateBookmarkList();
        }
    }
}
