// ShowKeyMapDlg.cpp : implementation file
//

#include "stdafx.h"

#include <io.h>

#include "MFCSDI.h"

#include "CVMEResource.h"
#include "MFCEditor.h"
#include "MFCEditorWnd.h"

#include "Resource.h"
#include "ShowKeyMapDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////

struct CmdText
{
    UINT nCmd;
    char *pszText;
};

CmdText CmdTextEntries[] = {
    { CVM_AUTOWRAPMODE,   "Auto wrap mode" },
    { CVM_INDENTMODE,     "Indent mode" },
    { CVM_TABSTYLE,       "Tab style" },
    { CVM_TRAILINGSPC,    "Trailing spaces" },
    { CVM_WRAPMODE,       "Wrap mode" },
    { CVM_WRAPONRESIZE,   "Wrap on resize" },
    { CVM_STARTSELECT,    "Start select" },
    { CVM_ENDSELECT,      "End select" },
    { CVM_HIDESELECT,     "Hide select" },
    { CVM_FINDMATCHING,   "Find matching" },
    { CVM_TOGGLEBOOKMARK, "Toggle bookmark" },
    { CVM_NEXTBOOKMARK,   "Next bookmark" },
    { CVM_PREVBOOKMARK,   "Previous bookmark" },
    { CVM_CLEARBOOKMARKS, "Clear bookmarks" },
    { CVM_GOTOLINE,       "Goto line" },
    { CVM_JUMPBLKST,      "Jump block start" },
    { CVM_JUMPBLKEND,     "Jump block end" },
    { CVM_LASTCHG,        "Jump to last change" },
    { CVM_PREVPOS,        "Jump to previous position" },
    { CVM_WRITEBLOCK,     "Write block to file" },
    { CVM_LOCALEDITOROPT, "Local editor options" },
    { CVM_BACKSPACE,      "Backspace" },
    { CVM_DELCHAR,        "Delete char" },
    { CVM_DELETETAB,      "Delete tab" },
    { CVM_DELWORDLEFT,    "Delete word left" },
    { CVM_DELWORDRIGHT,   "Delete word right" },
    { CVM_DELSTART,       "Delete to start of line" },
    { CVM_DELEND,         "Delete to end of line" },
    { CVM_DELLINE,        "Delete line" },
    { CVM_NEWLINE,        "Split line (new line)" },
    { CVM_INSERTLINE,     "Insert line" },
    { CVM_INSERTTAB,      "Insert tab" },
    { CVM_RESTORELINE,    "Restore line" },
    { CVM_COPYBLOCK,      "Copy block" },
    { CVM_MOVEBLOCK,      "Move block" },
    { CVM_READFILE,       "Read file" },
    { CVM_ALIGNTEXT,      "Align text" },
    { CVM_CENTERLINES,    "Center lines" },
    { CVM_FORCELOWER,     "Force to lower case" },
    { CVM_FORCEUPPER,     "Force to upper case" },
    { CVM_TOGGLECASE,     "Toggle case" },
    { CVM_INDENTBLOCK,    "Indent block" },
    { CVM_UNINDENTBLOCK,  "Unindent block" },
    { CVM_WRAPPARA,       "Word wrap paragraph" },
    { CVM_FILESAVEALL,    "Save all files" },
    { CVM_EDITFIND,       "Find text" },
    { CVM_EDITFINDNEXT,   "Find next occurrence" },
    { CVM_EDITREPLACE,    "Replace text" },
    { CVM_EDITCLEAR,      "Clear text" },
    { CVM_EDITCUT,        "Cut text to clipboard" },
    { CVM_EDITCOPY,       "Copy text to clipboard" },
    { CVM_EDITPASTE,      "Paste text from clipboard" },
    { CVM_EDITUNDO,       "Undo last change" },
    { CVM_EDITREDO,       "Redo last undone change" },
    { CVM_SELECT_ALL,     "Select all text" },
    { 0, NULL }
};

/////////////////////////////////////////////////////////////////////////////
// CShowKeyMapDlg dialog


CShowKeyMapDlg::CShowKeyMapDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CShowKeyMapDlg::IDD, pParent)
{
    // Make sure CVMEditorWndClass exists.  This only needs to be
    // done once.  It can be placed in the application's startup code
    // if CMFCEditorWnd is used in more than one dialog box
//    CMFCEditorWnd::RegisterControlClass();

	//{{AFX_DATA_INIT(CShowKeyMapDlg)
	//}}AFX_DATA_INIT

    m_pEditWin = NULL;
    m_nLastSel = LB_ERR;
}


void CShowKeyMapDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CShowKeyMapDlg)
	DDX_Control(pDX, IDC_HOTKEY, m_hkHotKey);
	DDX_Control(pDX, IDC_COMMANDLIST, m_lbCommandList);
	//}}AFX_DATA_MAP

    // CVMEditor DDX functions.  The first one connects the control
    // to the pointer.  The second sets/gets the text to a CString
    DDX_CVMEditorCtl(pDX, IDC_KEYMAPTEXT, &m_pEditWin);
//    DDX_CVMEditorText(pDX, IDC_KEYMAPTEXT, m_csText);
}

BEGIN_MESSAGE_MAP(CShowKeyMapDlg, CDialog)
	//{{AFX_MSG_MAP(CShowKeyMapDlg)
	ON_LBN_SELCHANGE(IDC_COMMANDLIST, OnSelchangeCommandlist)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CShowKeyMapDlg message handlers

BOOL CShowKeyMapDlg::OnInitDialog()
{
    char szKeyHelpFile[MAX_PATH], *pDirSep;

    CDialog::OnInitDialog();

    // Use a fixed font for the key map text
	m_EditFont.CreatePointFont(100, "Courier New");
    m_pEditWin->SetFontInfo(m_EditFont);

    // Load the key map text file from the expected location
    szKeyHelpFile[0] = '\x0';
    GetModuleFileName(NULL, szKeyHelpFile, sizeof(szKeyHelpFile));
    do
    {
        pDirSep = strrchr(szKeyHelpFile, '\\');
        if(pDirSep)
        {
            strcpy(pDirSep + 1, "KeyHelp.txt");
            if(!access(szKeyHelpFile, 0))
                break;
        }

        // Work back up the tree
        *pDirSep = '\x0';

    } while(pDirSep);

    m_pEditWin->editor->loadFileNow(szKeyHelpFile);

    // Load the key mappings into the list box.
    LoadKeyMap();

    m_lbCommandList.SetCurSel(0);
    OnSelchangeCommandlist();

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

// This is just a demo, so it only loads existing key mappings for the
// single key table and doesn't do much in the way of checking for
// duplicates.  Changes are not saved so will only have an effect on
// the current session.
void CShowKeyMapDlg::LoadKeyMap(void)
{
    HACCEL hAccel;
    LPACCEL pAccels;
    int nIdx, nCount;

    hAccel = (HACCEL)CVMEditor::GetKeyMapID(0);

    // If it's an ID rather than an accelerator handle, load it
    if(!((DWORD)hAccel & 0xFFFF0000))
        hAccel = LoadAccelerators(AfxGetInstanceHandle(), (LPTSTR)hAccel);

    nCount = CopyAcceleratorTable(hAccel, NULL, 0);
    if(!nCount)
        return;

    pAccels = new ACCEL[nCount];
    if(!pAccels)
        return;

    CopyAcceleratorTable(hAccel, pAccels, nCount);

    for(nIdx = 0; nIdx < nCount; nIdx++)
    {
        // Ignore secondary tables
        if(pAccels[nIdx].cmd >= CVM_LOADTABLE1 &&
          pAccels[nIdx].cmd <= CVM_LOADTABLE10)
            continue;

        FormatEntry(&pAccels[nIdx]);
    }

    delete [] pAccels;
}

void CShowKeyMapDlg::FormatEntry(LPACCEL pKey)
{
    DWORD dwCode;
    int nIdx;

    for(nIdx = 0; CmdTextEntries[nIdx].pszText; nIdx++)
        if(CmdTextEntries[nIdx].nCmd == pKey->cmd)
            break;

    if(!CmdTextEntries[nIdx].pszText)
        return;

    nIdx = m_lbCommandList.AddString(CmdTextEntries[nIdx].pszText);
    if(nIdx == LB_ERR)
        return;

    // Store the key as the item data
    dwCode = (pKey->fVirt << 16) | pKey->key;
    m_lbCommandList.SetItemData(nIdx, dwCode);
}

void CShowKeyMapDlg::OnSelchangeCommandlist()
{
    DWORD dwData;
    WORD  wCode, wMods;

    // Set hot key for last selected item
    if(m_nLastSel != LB_ERR)
    {
        m_hkHotKey.GetHotKey(wCode, wMods);
        m_lbCommandList.SetItemData(m_nLastSel, ((wMods << 18) | wCode));
    }

    m_nLastSel = m_lbCommandList.GetCurSel();
    dwData = m_lbCommandList.GetItemData(m_nLastSel);
    m_hkHotKey.SetHotKey((WORD)(dwData & 0x0000FFFF),
        (WORD)((dwData >> 18) & 0x0007));
}

void CShowKeyMapDlg::OnOK() 
{
    HACCEL hAccel;
    LPACCEL pAccels;
    DWORD dwData;
    int nIdx, nLBIdx, nCmdIdx, nCount;

    hAccel = (HACCEL)CVMEditor::GetKeyMapID(0);

    // If it's an ID rather than an accelerator handle, load it
    if(!((DWORD)hAccel & 0xFFFF0000))
        hAccel = LoadAccelerators(AfxGetInstanceHandle(), (LPTSTR)hAccel);

    nCount = CopyAcceleratorTable(hAccel, NULL, 0);
    if(!nCount)
        return;

    pAccels = (LPACCEL)LocalAlloc(LPTR, nCount * sizeof(ACCEL));
    if(!pAccels)
        return;

    CopyAcceleratorTable(hAccel, pAccels, nCount);

    for(nIdx = nLBIdx = 0; nIdx < nCount; nIdx++)
    {
        // Ignore unknown commands
        for(nCmdIdx = 0; CmdTextEntries[nCmdIdx].pszText; nCmdIdx++)
            if(CmdTextEntries[nCmdIdx].nCmd == pAccels[nIdx].cmd)
                break;

        if(!CmdTextEntries[nCmdIdx].pszText)
            continue;

        // Modify the key code for each accelerator
        dwData = m_lbCommandList.GetItemData(nLBIdx);
        pAccels[nIdx].fVirt = (UCHAR)((dwData >> 16) | 1);
        pAccels[nIdx].key = (WORD)(dwData & 0x0000FFFF);
        nLBIdx++;
    }

    // Create the new accelerator table and tell the editor to
    // use it.  If this table replaces another table that
    // was user-created, it will be destroyed automatically.
    hAccel = CreateAcceleratorTable(pAccels, nCount);
    CVMEditor::changeKeyMap(0, (DWORD)hAccel);

	CDialog::OnOK();
}
